==> crm-commom-vo-1.3.0.6.93.release.jar: com/biz/crm/nebular/mdm/terminal/MdmTerminalVo.java <==
package com.biz.crm.nebular.mdm.terminal;

import com.biz.crm.config.CrmColumnResolve;
import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmTreeVo;
import com.biz.crm.nebular.mdm.constant.DictConstant;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.List;

/**
 * @author Liao Hua
 * @date 2020/9/3 11:18 上午
 */
@Data
@EqualsAndHashCode(callSuper = false)
@CrmColumnResolve
public class MdmTerminalVo extends CrmTreeVo {
    @ApiModelProperty("门店编码查询条件")
    private List<String> terminalCodeList;
    @ApiModelProperty("左侧组织查询编码")
    private String code;
    @ApiModelProperty("左侧组织查询编码集合")
    private List<String> orgCodeList;
    @ApiModelProperty("终端编码")
    private String terminalCode;
    @ApiModelProperty("终端名称")
    private String terminalName;
    @ApiModelProperty("终端类型")
    private String terminalType;
    @ApiModelProperty("终端类型名称")
    @CrmDict(typeCode = DictConstant.TERMINAL_TYPE,dictCodeField = "terminalType")
    private String terminalTypeName;
    @ApiModelProperty("所属组织编码")
    private String orgCode;
    @ApiModelProperty("所属组织名字")
    private String orgName;
    @ApiModelProperty("客户组织编码")
    private String customerOrgCode;
    @ApiModelProperty("客户组织名称")
    private String customerOrgName;
    @ApiModelProperty("渠道")
    private String channel;
    @ApiModelProperty("渠道名字")
    @CrmDict(typeCode = DictConstant.CHANNEL,dictCodeField = "channel")
    private String channelName;
    @ApiModelProperty("营业执照法人姓名")
    private String licensePersonName;
    @ApiModelProperty("营业执照注册号")
    private String licenseRegisterNumber;
    @ApiModelProperty("营业执照企业名称")
    private String licenseFirmName;
    @ApiModelProperty("终端地址")
    private String terminalAddress;
    @ApiModelProperty("省编码")
    private String provinceCode;
    @ApiModelProperty("市编码")
    private String cityCode;
    @ApiModelProperty("区编码")
    private String districtCode;
    @ApiModelProperty("店招照片")
    private String shopImagePath;
    @ApiModelProperty("营业执照照片")
    private String licenseImagePath;
    @ApiModelProperty("经度")
    private String longitude;
    @ApiModelProperty("纬度")
    private String latitude;
    @ApiModelProperty("客户分类")
    private String customerClassification;
    @ApiModelProperty("审批状态,枚举ActApproveStatusEnum")
    private String actApproveStatus;
    @ApiModelProperty("联系人信息集合")
    private List<MdmTerminalContactVo> contacts;
    @ApiModelProperty("供货关系集合")
    private List<MdmTerminalSupplyVo> supplys;
    @ApiModelProperty("合作状态")
    private String cooperateStatus;
}

==> crm-commom-vo-1.4.0.4.release.jar: com/biz/crm/nebular/mdm/terminal/MdmTerminalVo.java <==
package com.biz.crm.nebular.mdm.terminal;

import com.biz.crm.config.CrmColumnResolve;
import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmTreeVo;
import com.biz.crm.nebular.mdm.constant.DictConstant;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.List;

/**
 * @author Liao Hua
 * @date 2020/9/3 11:18 上午
 */
@Data
@EqualsAndHashCode(callSuper = false)
@CrmColumnResolve
public class MdmTerminalVo extends CrmTreeVo {
    @ApiModelProperty("门店编码查询条件")
    private List<String> terminalCodeList;
    @ApiModelProperty("左侧组织查询编码")
    private String code;
    @ApiModelProperty("左侧组织查询编码集合")
    private List<String> orgCodeList;
    @ApiModelProperty("终端编码")
    private String terminalCode;
    @ApiModelProperty("终端名称")
    private String terminalName;
    @ApiModelProperty("终端类型")
    private String terminalType;
    @ApiModelProperty("终端类型名称")
    @CrmDict(typeCode = DictConstant.TERMINAL_TYPE,dictCodeField = "terminalType")
    private String terminalTypeName;
    @ApiModelProperty("所属组织编码")
    private String orgCode;
    @ApiModelProperty("所属组织名字")
    private String orgName;
    @ApiModelProperty("客户组织编码")
    private String customerOrgCode;
    @ApiModelProperty("客户组织名称")
    private String customerOrgName;
    @ApiModelProperty("渠道")
    private String channel;
    @ApiModelProperty("渠道名字")
    @CrmDict(typeCode = DictConstant.CHANNEL,dictCodeField = "channel")
    private String channelName;
    @ApiModelProperty("营业执照法人姓名")
    private String licensePersonName;
    @ApiModelProperty("营业执照注册号")
    private String licenseRegisterNumber;
    @ApiModelProperty("营业执照企业名称")
    private String licenseFirmName;
    @ApiModelProperty("终端地址")
    private String terminalAddress;
    @ApiModelProperty("省编码")
    private String provinceCode;
    @ApiModelProperty("市编码")
    private String cityCode;
    @ApiModelProperty("区编码")
    private String districtCode;
    @ApiModelProperty("店招照片")
    private String shopImagePath;
    @ApiModelProperty("营业执照照片")
    private String licenseImagePath;
    @ApiModelProperty("经度")
    private String longitude;
    @ApiModelProperty("纬度")
    private String latitude;
    @ApiModelProperty("客户分类")
    private String customerClassification;
    @ApiModelProperty("审批状态,枚举ActApproveStatusEnum")
    private String actApproveStatus;
    @ApiModelProperty("联系人信息集合")
    private List<MdmTerminalContactVo> contacts;
    @ApiModelProperty("供货关系集合")
    private List<MdmTerminalSupplyVo> supplys;
    @ApiModelProperty("合作状态")
    private String cooperateStatus;

    @ApiModelProperty("kms关联客户门店id")
    private String storeId;

    @ApiModelProperty("kms直营体系id")
    private String directSystemId;

    @ApiModelProperty("kms售达方id")
    private String sellPartyId;
}
